@@ -1,7 +1,7 @@
 //muroarstream.c:
 
 /*
- *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2009-2013
+ *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2009-2014
  *
  *  This file is part of µRoar,
  *  a minimalist library to access a RoarAudio Sound Server.
@@ -108,6 +108,9 @@ void run_stream(muroar_t stream, int file, int tx) {
  }
 }
 
+#define __check_argc(num) if ( (argc - i) <= (num) ) { fprintf(stderr, "Error: Invalid number of arguments.\n"); \
+                                                       return 64; }
+
 #ifdef __YIFF__
 yiff_uint_least16_t yiff_main(yiff_usize_t argc, char * argv[]) {
 #else
@@ -137,16 +140,22 @@ int main (int argc, char *argv[]) {
    usage(argv[0]);
    return 0;
   } else if ( !strcmp(k, "--file") || !strcmp(k, "-f") ) {
+   __check_argc(1)
    file = argv[++i];
   } else if ( !strcmp(k, "--server") ) {
+   __check_argc(1)
    server = argv[++i];
   } else if ( !strcmp(k, "--rate") || !strcmp(k, "-R") ) {
+   __check_argc(1)
    rate = atoi(argv[++i]);
   } else if ( !strcmp(k, "--channels") || !strcmp(k, "-C") ) {
+   __check_argc(1)
    chans = str2chans(argv[++i]);
   } else if ( !strcmp(k, "--bits") || !strcmp(k, "-B") ) {
+   __check_argc(1)
    bits = atoi(argv[++i]);
   } else if ( !strcmp(k, "--codec") || !strcmp(k, "-E") ) {
+   __check_argc(1)
    codec = str2codec(argv[++i]);
   } else if ( !strcmp(k, "--play") ) {
    tx = 1;
